@@ -181,6 +181,7 @@ KLineal::KLineal( QWidget *parent )
 
 KLineal::~KLineal()
 {
+  saveSettings();
   delete mTrayIcon;
 }
 
@@ -501,11 +502,6 @@ void KLineal::showMenu()
   mMenu->popup( pos );
 }
 
-bool KLineal::isResizing() const
-{
-  return mouseGrabber() == this && ( mRulerState == StateBegin || mRulerState == StateEnd );
-}
-
 int KLineal::length() const
 {
   return mHorizontal ? width() : height();
@@ -590,43 +586,6 @@ void KLineal::leaveEvent( QEvent *e )
   update();
 }
 
-void KLineal::mouseMoveEvent( QMouseEvent *inEvent )
-{
-  Q_UNUSED( inEvent );
-
-  if ( mRulerState >= StateMove ) {
-    if ( mouseGrabber() != this ) {
-      return;
-    }
-    if ( mRulerState == StateMove ) {
-      move( QCursor::pos() - mDragOffset );
-    } else if ( mRulerState == StateBegin ) {
-      QRect r = geometry();
-      if ( mHorizontal ) {
-        r.setLeft( QCursor::pos().x() - mDragOffset.x() );
-      } else {
-        r.setTop( QCursor::pos().y() - mDragOffset.y() );
-      }
-      setGeometry( r );
-    } else if ( mRulerState == StateEnd ) {
-      QPoint end = QCursor::pos() + mDragOffset - pos();
-      QSize size = mHorizontal
-        ? QSize( end.x(), height() )
-        : QSize( width(), end.y() );
-      resize( size );
-    }
-  } else {
-    QPoint cpos = localCursorPos();
-    mRulerState = StateNone;
-    if ( beginRect().contains( cpos ) || endRect().contains( cpos) ) {
-      setCursor( resizeCursor() );
-    } else {
-      setCursor( mCrossCursor );
-    }
-    update();
-  }
-}
-
 /**
  * overwritten for dragging and context menu
  */
@@ -637,22 +596,12 @@ void KLineal::mousePressEvent( QMouseEvent *inEvent )
   QRect gr = geometry();
   mDragOffset = mLastClickPos - gr.topLeft();
   if ( inEvent->button() == Qt::LeftButton ) {
-    if ( mRulerState < StateMove ) {
-      if ( beginRect().contains( mDragOffset ) ) {
-        mRulerState = StateBegin;
-        grabMouse( resizeCursor() );
-      } else if ( endRect().contains( mDragOffset ) ) {
-        mDragOffset = gr.bottomRight() - mLastClickPos;
-        mRulerState = StateEnd;
-        grabMouse( resizeCursor() );
-      } else {
-        if ( nativeMove() ) {
-          startNativeMove( inEvent );
-        } else {
-          mRulerState = StateMove;
-          grabMouse( Qt::SizeAllCursor );
-        }
-      }
+    if ( beginRect().contains( mDragOffset ) ) {
+      windowHandle()->startSystemResize(mHorizontal ? Qt::LeftEdge : Qt::TopEdge);
+    } else if ( endRect().contains( mDragOffset ) ) {
+      windowHandle()->startSystemResize(mHorizontal ? Qt::RightEdge : Qt::BottomEdge);
+    } else {
+      windowHandle()->startSystemMove();
     }
   } else if ( inEvent->button() == Qt::MiddleButton ) {
     mClicked = true;
@@ -662,55 +611,19 @@ void KLineal::mousePressEvent( QMouseEvent *inEvent )
   }
 }
 
-#ifdef KRULER_HAVE_X11
-bool KLineal::nativeMove() const
-{
-  return QX11Info::isPlatformX11() && RulerSettings::self()->nativeMoving();
-}
-
-void KLineal::startNativeMove( QMouseEvent *inEvent )
-{
-  xcb_ungrab_pointer( QX11Info::connection(), QX11Info::appTime() );
-  NETRootInfo wm_root( QX11Info::connection(), NET::WMMoveResize );
-  wm_root.moveResizeRequest( winId(), inEvent->globalX(), inEvent->globalY(), NET::Move );
-}
-
-void KLineal::stopNativeMove( QMouseEvent *inEvent )
-{
-  NETRootInfo wm_root( QX11Info::connection(), NET::WMMoveResize );
-  wm_root.moveResizeRequest( winId(), inEvent->globalX(), inEvent->globalY(), NET::MoveResizeCancel );
-}
-#else
-bool KLineal::nativeMove() const
-{
-  return false;
-}
-
-void KLineal::startNativeMove( QMouseEvent *inEvent )
+void KLineal::mouseMoveEvent( QMouseEvent *inEvent )
 {
   Q_UNUSED( inEvent );
-}
-
-void KLineal::stopNativeMove( QMouseEvent *inEvent )
-{
-  Q_UNUSED( inEvent );
-}
-#endif
-
-/**
- * overwritten for dragging
- */
-void KLineal::mouseReleaseEvent( QMouseEvent *inEvent )
-{
-  if ( mRulerState != StateNone ) {
-    mRulerState = StateNone;
-    releaseMouse();
-    saveSettings();
-  } else if ( nativeMove() ) {
-    stopNativeMove( inEvent );
+  QPoint cpos = localCursorPos();
+  if ( beginRect().contains( cpos ) || endRect().contains( cpos) ) {
+    setCursor( resizeCursor() );
+  } else {
+    setCursor( mCrossCursor );
   }
+  update();
 }
 
+
 void KLineal::wheelEvent( QWheelEvent *e )
 {
   int numDegrees = e->angleDelta().y() / 8;
@@ -936,7 +849,7 @@ void KLineal::paintEvent(QPaintEvent *inEvent )
 
   drawResizeHandle( painter, mHorizontal ? Qt::LeftEdge : Qt::TopEdge );
   drawResizeHandle( painter, mHorizontal ? Qt::RightEdge : Qt::BottomEdge );
-  if ( underMouse() && !isResizing() ) {
+  if ( underMouse() ) {
     int xy = mHorizontal ? localCursorPos().x() : localCursorPos().y();
     drawIndicatorOverlay( painter, xy );
     drawIndicatorText( painter, xy );
